@@ -127,6 +127,7 @@ fluid_defsfont_sfont_get_preset(fluid_sfont_t* sfont, unsigned int bank, unsigne
     return NULL;
   }
 
+  preset->sfont = sfont;
   preset->data = defpreset;
   preset->free = fluid_defpreset_preset_delete;
   preset->get_name = fluid_defpreset_preset_get_name;
@@ -158,7 +159,7 @@ int fluid_defsfont_sfont_iteration_next(fluid_sfont_t* sfont, fluid_preset_t* pr
 int fluid_defpreset_preset_delete(fluid_preset_t* preset)
 {
   FLUID_FREE(preset);
-  printf("TODO: free modulators\n"); 
+/*   printf("TODO: free modulators\n");  */
   return 0;
 }
 
@@ -646,7 +647,7 @@ fluid_defpreset_noteon(fluid_defpreset_t* preset, fluid_synth_t* synth, int chan
 	    if (inst_zone->gen[i].flags){
 	      fluid_voice_gen_set(voice, i, inst_zone->gen[i].val);
 
-	    } else if (global_inst_zone != NULL && global_inst_zone->gen[i].flags){
+	    } else if ((global_inst_zone != NULL) && (global_inst_zone->gen[i].flags)) {
 	      fluid_voice_gen_set(voice, i, global_inst_zone->gen[i].val);		  
 
 	    } else {
@@ -732,9 +733,9 @@ fluid_defpreset_noteon(fluid_defpreset_t* preset, fluid_synth_t* synth, int chan
 	       * generator.  The effect is -added- to the destination
 	       * summing node -> voice_gen_incr */
 
-	      if (preset_zone->gen[i].flags){
+	      if (preset_zone->gen[i].flags) {
 		fluid_voice_gen_incr(voice, i, preset_zone->gen[i].val);
-	      } else if ((global_preset_zone != NULL) && global_preset_zone->gen[i].flags){
+	      } else if ((global_preset_zone != NULL) && global_preset_zone->gen[i].flags) {
 		fluid_voice_gen_incr(voice, i, global_preset_zone->gen[i].val);		  
 	      } else {
 		/* The generator has not been defined in this preset
