@@ -801,12 +801,14 @@ int fluid_midi_dump_prerouter(void* data, fluid_midi_event_t* event)
 	fflush(stdout);
 	break;
       case NOTE_OFF:
-	fprintf(stdout, "event_pre_noteoff %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_pre_noteoff %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	fflush(stdout);
 	break;
 	break;
       case CONTROL_CHANGE:
-	fprintf(stdout, "event_pre_cc %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_pre_cc %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	fflush(stdout);
 	break;
       case PROGRAM_CHANGE:
@@ -822,7 +824,8 @@ int fluid_midi_dump_prerouter(void* data, fluid_midi_event_t* event)
 	fflush(stdout);
 	break;
       case KEY_PRESSURE:
-	fprintf(stdout, "event_pre_kpress %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_pre_kpress %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	fflush(stdout);
 	break;
       default:
@@ -837,19 +840,23 @@ int fluid_midi_dump_prerouter(void* data, fluid_midi_event_t* event)
  * Again, it prints a message to stdout and hands the event on to the synth.
  * It is not a part of the MIDI router, but an added link in the MIDI chain.
  */
-int fluid_midi_dump_postrouter(void* data, fluid_midi_event_t* event){
+int fluid_midi_dump_postrouter(void* data, fluid_midi_event_t* event)
+{
   switch (event->type) {
       case NOTE_ON:
-	fprintf(stdout, "event_post_noteon %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_post_noteon %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	fflush(stdout);
 	break;
       case NOTE_OFF:
-	fprintf(stdout, "event_post_noteoff %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_post_noteoff %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	fflush(stdout);
 	break;
 	break;
       case CONTROL_CHANGE:
-	fprintf(stdout, "event_post_cc %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_post_cc %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	fflush(stdout);
 	break;
       case PROGRAM_CHANGE:
@@ -862,7 +869,8 @@ int fluid_midi_dump_postrouter(void* data, fluid_midi_event_t* event){
 	fprintf(stdout, "event_post_cpress %i %i\n", event->channel, event->param1);
 	break;
       case KEY_PRESSURE:
-	fprintf(stdout, "event_post_kpress %i %i %i\n", event->channel, event->param1, event->param2);
+	fprintf(stdout, "event_post_kpress %i %i %i\n", 
+		event->channel, event->param1, event->param2);
 	break;
       default:
 	break;
